@@ -18,12 +18,12 @@ import (
 
 // initLoadBalancerHealthChecker initializes the health check server for
 // ServiceTypeLoadBalancer services
-func initLoadBalancerHealthChecker(nodeName string, wf *factory.WatchFactory) error {
+func initLoadBalancerHealthChecker(nodeName string, wf *factory.WatchFactory) {
 	server := healthcheck.NewServer(nodeName, nil, nil, nil)
 	services := make(map[ktypes.NamespacedName]uint16)
 	endpoints := make(map[ktypes.NamespacedName]int)
 
-	_, err := wf.AddServiceHandler(cache.ResourceEventHandlerFuncs{
+	wf.AddServiceHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc: func(obj interface{}) {
 			svc := obj.(*kapi.Service)
 			if svc.Spec.HealthCheckNodePort != 0 {
@@ -45,11 +45,8 @@ func initLoadBalancerHealthChecker(nodeName string, wf *factory.WatchFactory) er
 			}
 		},
 	}, nil)
-	if err != nil {
-		return err
-	}
 
-	_, err = wf.AddEndpointsHandler(cache.ResourceEventHandlerFuncs{
+	wf.AddEndpointsHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc: func(obj interface{}) {
 			ep := obj.(*kapi.Endpoints)
 			name := ktypes.NamespacedName{Namespace: ep.Namespace, Name: ep.Name}
@@ -73,7 +70,6 @@ func initLoadBalancerHealthChecker(nodeName string, wf *factory.WatchFactory) er
 			_ = server.SyncEndpoints(endpoints)
 		},
 	}, nil)
-	return err
 }
 
 func countLocalEndpoints(ep *kapi.Endpoints, nodeName string) int {
@@ -98,7 +94,7 @@ func checkForStaleOVSInterfaces(stopChan chan struct{}) {
 			stdout, _, err := util.RunOVSVsctl("--data=bare", "--no-headings", "--columns=name", "find",
 				"interface", "ofport=-1")
 			if err != nil {
-				klog.Errorf("failed to list OVS interfaces with ofport set to -1")
+				klog.Errorf("Failed to list OVS interfaces with ofport set to -1")
 				continue
 			}
 			if len(stdout) == 0 {
@@ -106,10 +102,10 @@ func checkForStaleOVSInterfaces(stopChan chan struct{}) {
 			}
 			values := strings.Split(stdout, "\n\n")
 			for _, val := range values {
-				klog.Warningf("found stale interface %s, so deleting it", val)
+				klog.Warningf("Found stale interface %s, so deleting it", val)
 				_, stderr, err := util.RunOVSVsctl("--if-exists", "--with-iface", "del-port", val)
 				if err != nil {
-					klog.Errorf("failed to delete OVS port/interface %s: stderr: %s (%v)",
+					klog.Errorf("Failed to delete OVS port/interface %s: stderr: %s (%v)",
 						val, stderr, err)
 				}
 			}
@@ -130,12 +126,12 @@ func checkDefaultConntrackRules(gwBridge string, physIntf, patchIntf, ofportPhys
 			out, _, err := util.RunOVSOfctl("dump-aggregate", gwBridge,
 				fmt.Sprintf("cookie=%s/-1", defaultOpenFlowCookie))
 			if err != nil {
-				klog.Errorf("failed to dump aggregate statistics of the default OpenFlow rules: %v", err)
+				klog.Errorf("Failed to dump aggregate statistics of the default OpenFlow rules: %v", err)
 				continue
 			}
 
 			if !strings.Contains(out, flowCount) {
-				klog.Errorf("fatal error: unexpected default OpenFlows count, expect %d output: %v\n",
+				klog.Errorf("Fatal error: unexpected default OpenFlows count, expect %d output: %v\n",
 					nFlows, out)
 				os.Exit(1)
 			}
@@ -148,7 +144,7 @@ func checkDefaultConntrackRules(gwBridge string, physIntf, patchIntf, ofportPhys
 				continue
 			}
 			if ofportPatch != curOfportPatch {
-				klog.Errorf("fatal error: ofport of %s has changed from %s to %s",
+				klog.Errorf("Fatal error: ofport of %s has changed from %s to %s",
 					patchIntf, ofportPatch, curOfportPatch)
 				os.Exit(1)
 			}
@@ -161,7 +157,7 @@ func checkDefaultConntrackRules(gwBridge string, physIntf, patchIntf, ofportPhys
 				continue
 			}
 			if ofportPhys != curOfportPhys {
-				klog.Errorf("fatal error: ofport of %s has changed from %s to %s",
+				klog.Errorf("Fatal error: ofport of %s has changed from %s to %s",
 					physIntf, ofportPhys, curOfportPhys)
 				os.Exit(1)
 			}
